pub(crate) struct DecodeLoadoutInput {
loadout: String,
}Expand description
Input for the talent loadout decoder MCP tool.
Fields
loadout: StringTrait Implementations
Sourceimpl Debug for DecodeLoadoutInput
impl Debug for DecodeLoadoutInput
Sourceimpl Default for DecodeLoadoutInput
impl Default for DecodeLoadoutInput
Sourcefn default() -> DecodeLoadoutInput
fn default() -> DecodeLoadoutInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DecodeLoadoutInput
impl<'de> Deserialize<'de> for DecodeLoadoutInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecodeLoadoutInput
impl JsonSchema for DecodeLoadoutInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DecodeLoadoutInput
impl RefUnwindSafe for DecodeLoadoutInput
impl Send for DecodeLoadoutInput
impl Sync for DecodeLoadoutInput
impl Unpin for DecodeLoadoutInput
impl UnsafeUnpin for DecodeLoadoutInput
impl UnwindSafe for DecodeLoadoutInput